==> camel-k-model-v1-5.3.0-sources.jar: io/fabric8/camelk/v1/ArtifactFluent.java <==
package io.fabric8.camelk.v1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface ArtifactFluent<A extends ArtifactFluent<A>> extends Fluent<A> {


    public String getChecksum();
    public A withChecksum(String checksum);
    public Boolean hasChecksum();
    public A withNewChecksum(StringBuilder arg1);
    public A withNewChecksum(int[] arg1,int arg2,int arg3);
    public A withNewChecksum(char[] arg1);
    public A withNewChecksum(StringBuffer arg1);
    public A withNewChecksum(byte[] arg1,int arg2);
    public A withNewChecksum(byte[] arg1);
    public A withNewChecksum(char[] arg1,int arg2,int arg3);
    public A withNewChecksum(byte[] arg1,int arg2,int arg3);
    public A withNewChecksum(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewChecksum(String arg1);
    public String getId();
    public A withId(String id);
    public Boolean hasId();
    public A withNewId(StringBuilder arg1);
    public A withNewId(int[] arg1,int arg2,int arg3);
    public A withNewId(char[] arg1);
    public A withNewId(StringBuffer arg1);
    public A withNewId(byte[] arg1,int arg2);
    public A withNewId(byte[] arg1);
    public A withNewId(char[] arg1,int arg2,int arg3);
    public A withNewId(byte[] arg1,int arg2,int arg3);
    public A withNewId(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewId(String arg1);
    public String getLocation();
    public A withLocation(String location);
    public Boolean hasLocation();
    public A withNewLocation(StringBuilder arg1);
    public A withNewLocation(int[] arg1,int arg2,int arg3);
    public A withNewLocation(char[] arg1);
    public A withNewLocation(StringBuffer arg1);
    public A withNewLocation(byte[] arg1,int arg2);
    public A withNewLocation(byte[] arg1);
    public A withNewLocation(char[] arg1,int arg2,int arg3);
    public A withNewLocation(byte[] arg1,int arg2,int arg3);
    public A withNewLocation(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewLocation(String arg1);
    public String getTarget();
    public A withTarget(String target);
    public Boolean hasTarget();
    public A withNewTarget(StringBuilder arg1);
    public A withNewTarget(int[] arg1,int arg2,int arg3);
    public A withNewTarget(char[] arg1);
    public A withNewTarget(StringBuffer arg1);
    public A withNewTarget(byte[] arg1,int arg2);
    public A withNewTarget(byte[] arg1);
    public A withNewTarget(char[] arg1,int arg2,int arg3);
    public A withNewTarget(byte[] arg1,int arg2,int arg3);
    public A withNewTarget(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewTarget(String arg1);
}

==> camel-k-model-v1-5.3.1-sources.jar: io/fabric8/camelk/v1/ArtifactFluent.java <==
package io.fabric8.camelk.v1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface ArtifactFluent<A extends ArtifactFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getChecksum();
    public A withChecksum(String checksum);
    public Boolean hasChecksum();
    public A withNewChecksum(StringBuilder arg1);
    public A withNewChecksum(int[] arg1,int arg2,int arg3);
    public A withNewChecksum(char[] arg1);
    public A withNewChecksum(StringBuffer arg1);
    public A withNewChecksum(byte[] arg1,int arg2);
    public A withNewChecksum(byte[] arg1);
    public A withNewChecksum(char[] arg1,int arg2,int arg3);
    public A withNewChecksum(byte[] arg1,int arg2,int arg3);
    public A withNewChecksum(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewChecksum(String arg1);
    public String getId();
    public A withId(String id);
    public Boolean hasId();
    public A withNewId(StringBuilder arg1);
    public A withNewId(int[] arg1,int arg2,int arg3);
    public A withNewId(char[] arg1);
    public A withNewId(StringBuffer arg1);
    public A withNewId(byte[] arg1,int arg2);
    public A withNewId(byte[] arg1);
    public A withNewId(char[] arg1,int arg2,int arg3);
    public A withNewId(byte[] arg1,int arg2,int arg3);
    public A withNewId(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewId(String arg1);
    public String getLocation();
    public A withLocation(String location);
    public Boolean hasLocation();
    public A withNewLocation(StringBuilder arg1);
    public A withNewLocation(int[] arg1,int arg2,int arg3);
    public A withNewLocation(char[] arg1);
    public A withNewLocation(StringBuffer arg1);
    public A withNewLocation(byte[] arg1,int arg2);
    public A withNewLocation(byte[] arg1);
    public A withNewLocation(char[] arg1,int arg2,int arg3);
    public A withNewLocation(byte[] arg1,int arg2,int arg3);
    public A withNewLocation(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewLocation(String arg1);
    public String getTarget();
    public A withTarget(String target);
    public Boolean hasTarget();
    public A withNewTarget(StringBuilder arg1);
    public A withNewTarget(int[] arg1,int arg2,int arg3);
    public A withNewTarget(char[] arg1);
    public A withNewTarget(StringBuffer arg1);
    public A withNewTarget(byte[] arg1,int arg2);
    public A withNewTarget(byte[] arg1);
    public A withNewTarget(char[] arg1,int arg2,int arg3);
    public A withNewTarget(byte[] arg1,int arg2,int arg3);
    public A withNewTarget(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewTarget(String arg1);
}
